@@ -1961,7 +1961,7 @@ osi_bool osi_config_generate_id( OSI_SCAN_CONFIG *cfg )
 
             /* ignore comments and empty lines. */
 
-            if ( ( line != NULL ) && ( line[0] != 0 ) && ( line[0] != '#' ) )
+            if ( ( line != NULL ) && ( line[0] != 0 ) )
             {
                 unsigned int position             = 0;
                 unsigned int config_line_position = 0;
