@@ -261,7 +261,7 @@ int eflags;
 
 
 
-//static char *regatoi(const regex_t *preg, char *localbuf);
+/* static char *regatoi(const regex_t *preg, char *localbuf); */
 
 /*
  = #define  REG_OKAY     0
@@ -424,9 +424,10 @@ static int freezeset(register struct parse *p, register cset *cs);
 static int firstch(register struct parse *p, register cset *cs);
 static int nch(register struct parse *p, register cset *cs);
 static void mcadd(register struct parse *p, register cset *cs, register char *cp);
-//static void mcsub(register cset *cs, register char *cp);
-//static int mcin(register cset *cs, register char *cp);
-//static char *mcfind(register cset *cs, register char *cp);
+/*static void mcsub(register cset *cs, register char *cp);
+static int mcin(register cset *cs, register char *cp);
+static char *mcfind(register cset *cs, register char *cp);
+*/
 static void mcinvert(register struct parse *p, register cset *cs);
 static void mccase(register struct parse *p, register cset *cs);
 static int isinsets(register struct re_guts *g, int c);
