@@ -311,6 +311,10 @@ void wrap_scan_record( SCAN_RECORD *scan_record )
             case SCAN_RECORD_TYPE_UNIX_1:
             {
                 SCAN_RECORD_UNIX_1 *record = (SCAN_RECORD_UNIX_1 *)scan_record;
+                char buffer[sizeof(record->path)] = "";
+
+                escape_filename( record->path, buffer, sizeof(buffer) );
+                osi_strlcpy( record->path, buffer, sizeof(record->path) );
 
                 record->filter 	 	   = htons( record->filter );
                 record->checksum_algorithm =htons( record->checksum_algorithm );
@@ -340,6 +344,10 @@ void wrap_scan_record( SCAN_RECORD *scan_record )
             case SCAN_RECORD_TYPE_WINNT_1:
             {
                SCAN_RECORD_WINNT_1 *record = (SCAN_RECORD_WINNT_1 *)scan_record;
+                char buffer[sizeof(record->path)] = "";
+
+                escape_filename( record->path, buffer, sizeof(buffer) );
+                osi_strlcpy( record->path, buffer, sizeof(record->path) );
 
                 record->filter 	    = htons( record->filter );
                 record->checksum_algorithm =htons( record->checksum_algorithm );
@@ -353,6 +361,18 @@ void wrap_scan_record( SCAN_RECORD *scan_record )
             }
                 break;
 
+            case SCAN_RECORD_TYPE_TEXT_1:
+            {
+               SCAN_RECORD_TEXT_1 *record = (SCAN_RECORD_TEXT_1 *)scan_record;
+                char buffer[sizeof(record->data)] = "";
+
+                escape_filename( record->name, buffer, sizeof(buffer) );
+                osi_strlcpy( record->name, buffer, sizeof(record->name) );
+                escape_filename( record->data, buffer, sizeof(buffer) );
+                osi_strlcpy( record->data, buffer, sizeof(record->data) );
+            }
+                break;
+
             default:
                 break;
         }
@@ -1059,7 +1079,6 @@ void get_win32_file_attr_delta_string( osi_uint64 before, osi_uint64 after,
     deltas = ( before ^ after );
 
     /* now go through and figure out if each delta was added or is missing. */
-
     
     for( index = 0; win32_attr_descriptions[index].word != NULL; index++ )
     {
@@ -1071,7 +1090,7 @@ void get_win32_file_attr_delta_string( osi_uint64 before, osi_uint64 after,
                 osi_strlcat( buffer, win32_attr_descriptions[index].word,
                              buffer_size );
 
-                osi_strlcat( buffer, ",", buffer_size );
+                osi_strlcat( buffer, "][", buffer_size );
             }
 
             else
@@ -1080,7 +1099,7 @@ void get_win32_file_attr_delta_string( osi_uint64 before, osi_uint64 after,
                osi_strlcat( buffer, win32_attr_descriptions[index].word,
                             buffer_size );
 
-               osi_strlcat( buffer, ",", buffer_size );
+               osi_strlcat( buffer, "][", buffer_size );
             }
         }
     }
@@ -1092,3 +1111,4 @@ void get_win32_file_attr_delta_string( osi_uint64 before, osi_uint64 after,
         buffer[strlen(buffer)-1] = '\0';
     }
 }
+
