@@ -918,27 +918,44 @@ long osi_get_time()
 
 char * osi_time_to_string( long time )
 {
-    static char buf[40];
+    static char time_buffer[25];
+    time_t time_value = time;
+    char *time_string = (char *)ctime( &time_value );
 
-    time_t curtime;
-    struct tm *loc;
+    time_buffer[0] = '\0';
 
-    curtime = time;
-    loc = localtime( &curtime );
+    if( time_string != NULL )
+    {
+        osi_strlcpy( time_buffer, time_string, sizeof( time_buffer ) );
+        time_buffer[24] = '\0';
+    }
 
-    /* based on RFC 2822 it should be:
-    3.3. Date and Time Specification
-    ...
-    date-time       =       [ day-of-week "," ] date FWS time [CFWS]
-    ...
-    */
+    return time_buffer;                                       
+}  
 
-    strftime( buf, sizeof(buf) ,"%a, %e %b %Y %H:%M:%S %z", loc );
-    buf[39] = '\0';
+#ifdef WIN32
+int get_tz_bias( char *buf, int buf_size )
+{
+   int zone;
+   int ret;
 
-    return buf;
+   TIME_ZONE_INFORMATION tzi;
+
+   ret = GetTimeZoneInformation(&tzi);
+
+   if ( ret == TIME_ZONE_ID_STANDARD ||
+        ret == TIME_ZONE_ID_DAYLIGHT )
+   {
+       zone = ((tzi.Bias/60) * -1 );
+       sprintf( buf, "%+03d00", zone );
+
+       return 0;
+   }
+
+   memset( buf, 0, buf_size );
+   return -1;
 }
-
+#endif /* WIN32 */
 
 
 /******************************************************************************
