@@ -2372,75 +2372,6 @@ exit_gracefully:
     return status;
 }
 
-osi_bool ctl_import_default_config( CTL_CONTEXT *context )
-{
-    osi_bool status = FALSE;
-
-    int client_socket;
-    int result;
-
-    osi_uint16 type;
-
-    MESSAGE req;
-    MESSAGE res;
-
-    CONTROL_REQUEST control_request;
-    memset( &control_request, 0, sizeof( CONTROL_REQUEST ) );
-
-    if( ( context == NULL ) || ( context->ssl == NULL ) )
-    {
-        return FALSE;
-    }
-
-    /* set command and wrap our control request. */
-
-    control_request.command = CONTROL_COMMAND_IMPORT_DEFAULT_CONFIG;
-
-    osi_strlcpy( control_request.host, context->host,
-                 sizeof( control_request.host ) );
-
-    osi_strlcpy( control_request.buffer, context->buffer,
-                 sizeof( control_request.buffer ) );
-
-    wrap_control_request( &control_request );
-    initialize_message( &req, MESSAGE_TYPE_CONTROL_REQUEST );
-
-    result = message_set_payload( &req, &control_request,
-                                  sizeof( control_request ), 0 );
-
-    /* send request message to management application. */
-
-    client_socket = SSL_get_fd( context->ssl );
-    osi_ssl_write_message( &req, context->ssl );
-
-    if( osi_ssl_read_message( &res, context->ssl ) != MESSAGE_OK )
-    {
-        context->error.type = OSI_ERROR_NO_RESPONSE;
-        goto exit_gracefully;
-    }
-
-    type = GET_MESSAGE_TYPE(((MESSAGE *)&res) );
-
-    if( type == MESSAGE_TYPE_SUCCESS )
-    {
-        status = TRUE;
-    }
-
-    if( type == MESSAGE_TYPE_ERROR )
-    {
-        OSI_ERROR *error = MESSAGE_TO_TYPE( &res, OSI_ERROR * );
-        unwrap_error( error );
-        context->error.type = error->type;
-
-        osi_strlcpy( context->error.message, error->message,
-                     sizeof( context->error.message ) );
-    }
-
-exit_gracefully:
-
-    return status;
-}
-
 osi_bool ctl_set_base_db( CTL_CONTEXT *context )
 {
     osi_bool status = FALSE;
