@@ -44,6 +44,7 @@ static struct h_keywords host_config_keywords[] =
     { "schedule_period", HOST_CONFIG_KEYWORD_SCHEDULE_PERIOD },
     { "db_flags", HOST_CONFIG_KEYWORD_DB_FLAGS },
     { "port", HOST_CONFIG_KEYWORD_PORT },
+    { "config", HOST_CONFIG_KEYWORD_CONFIG },
     { NULL, 0 }
 };
 
@@ -429,7 +430,13 @@ osi_bool osi_host_brief_write_file( const char *filepath,
                     osi_strlcat( temp_line, host_brief->base_db,
                                  sizeof( temp_line ) );
                     break;
-                
+
+                case HOST_CONFIG_KEYWORD_CONFIG:
+
+                    osi_strlcat( temp_line, host_brief->config,
+                                 sizeof( temp_line ) );
+                    break;
+
                 default:
                     break;
             }
@@ -476,6 +483,7 @@ osi_bool osi_host_brief_write_file( const char *filepath,
                         case HOST_CONFIG_KEYWORD_NOTIFY_EMAIL:
                         case HOST_CONFIG_KEYWORD_DB_FLAGS:
                         case HOST_CONFIG_KEYWORD_PORT:
+                        case HOST_CONFIG_KEYWORD_CONFIG:
 
                             break;
                         
@@ -654,6 +662,10 @@ osi_bool osi_host_config_update_data( OSI_HOST_CONFIG *config )
                 case HOST_CONFIG_KEYWORD_BASE_DB:
                     osi_strlcat( line, config->base_db, sizeof( line ) );
                     break;
+
+                case HOST_CONFIG_KEYWORD_CONFIG:
+                    osi_strlcat( line, config->config, sizeof( line ) );
+                    break;
                 
                 default:
                     break;
@@ -869,6 +881,16 @@ osi_bool parse_host_config_line( char *line, OSI_HOST_CONFIG *config )
                 }
 
                 break;
+
+            case HOST_CONFIG_KEYWORD_CONFIG:
+
+                if( get_host_config_line_value( line, value, sizeof( value ) ) )
+                {
+                    osi_strlcpy( config->config,
+                                 value, sizeof( config->config ) );
+                }
+
+                break;
                 
             case HOST_CONFIG_KEYWORD_COMMENT:
             
@@ -1061,7 +1083,17 @@ osi_bool parse_host_brief_line( char *line, OSI_HOST_BRIEF *host_brief )
                 }
 
                 break;
-                
+
+            case HOST_CONFIG_KEYWORD_CONFIG:
+
+                if( get_host_config_line_value( line, value, sizeof( value ) ) )
+                {
+                    osi_strlcpy( host_brief->config,
+                                 value, sizeof( host_brief->config) );
+                }
+
+                break;
+
             case HOST_CONFIG_KEYWORD_COMMENT:
             
                 /* suck up the rest of the line, do nothing with it. */
