@@ -112,11 +112,6 @@ struct h_keywords
     int  type;
 };
 
-/* 
-extern struct h_keywords host_config_keywords[];
-extern struct h_keywords h_boolean_keywords[];
-*/
-
 
 /* function prototypes. */
 
