@@ -76,7 +76,7 @@ static struct m_keywords management_config_keywords[] =
     { "http_port", MANAGEMENT_CONFIG_KEYWORD_HTTP_PORT },
     { "http_host", MANAGEMENT_CONFIG_KEYWORD_HTTP_HOST },
     { "notify_email", MANAGEMENT_CONFIG_KEYWORD_NOTIFY_EMAIL },
-    { "admin_email", MANAGEMENT_CONFIG_KEYWORD_ADMIN_EMAIL },
+    { "notify_app", MANAGEMENT_CONFIG_KEYWORD_NOTIFY_APP },
     { "notify_smtp_host", MANAGEMENT_CONFIG_KEYWORD_NOTIFY_SMTP_HOST },
     { "notify_smtp_port", MANAGEMENT_CONFIG_KEYWORD_NOTIFY_SMTP_PORT },
     { "hosts_directory", MANAGEMENT_CONFIG_KEYWORD_HOSTS_DIRECTORY },
@@ -381,9 +381,9 @@ osi_bool osi_management_config_write_file( const char *filepath,
    
                     break;
 
-               case MANAGEMENT_CONFIG_KEYWORD_ADMIN_EMAIL:
+               case MANAGEMENT_CONFIG_KEYWORD_NOTIFY_APP:
     
-                    osi_strlcat( line, config->admin_email,
+                    osi_strlcat( line, config->notify_app,
                                  sizeof( line ) );
     
                     osi_strlcat( line, "\n", sizeof( line ) );
@@ -552,9 +552,9 @@ osi_bool osi_management_config_sync( OSI_MANAGEMENT_CONFIG *config )
    
                 break;
 
-            case MANAGEMENT_CONFIG_KEYWORD_ADMIN_EMAIL:
+            case MANAGEMENT_CONFIG_KEYWORD_NOTIFY_APP:
 
-                osi_strlcat( line, config->admin_email, sizeof( line ) );
+                osi_strlcat( line, config->notify_app, sizeof( line ) );
                 string_list_add_item( config->data, line );
 
                 break;
@@ -687,15 +687,15 @@ osi_bool parse_management_config_line( char *line,
 
                 break;
 
-            case MANAGEMENT_CONFIG_KEYWORD_ADMIN_EMAIL:
+            case MANAGEMENT_CONFIG_KEYWORD_NOTIFY_APP:
 
                 get_management_config_line_value( line,
                                                   value, sizeof( value ) );
 
                 if( strlen( value ) > 0 )
                 {
-                    osi_strlcpy( config->admin_email, value,
-                                 sizeof( config->admin_email ) );
+                    osi_strlcpy( config->notify_app, value,
+                                 sizeof( config->notify_app) );
                 }
 
                 break;
