@@ -325,7 +325,7 @@ void process_ports_windows( SCANNER *scanner )
 
 #endif /* WIN32 */
 
-#if defined(DISABLED)
+#if defined(SYSTEM_LINUX)
 
 #define TCP_FILE  "/proc/net/tcp"
 #define TCP6_FILE "/proc/net/tcp6"
@@ -404,6 +404,13 @@ void process_proc_file( SCANNER *scanner, const char *filename )
             continue; 
         }
 
+        /* if UDP, and not open, we bail. */
+
+        if ( filename == UDP_FILE && strcmp( state, "07" ) != 0 )
+        {
+            continue;
+        }
+
         /* if local is either IPV4 or IPV6 127.0.0.1, bail. */
 
         if ( ( strcmp( local_addr, "0100007F" ) == 0 ) ||
@@ -463,7 +470,7 @@ void mod_ports( SCANNER *scanner )
     process_ports_windows( scanner );
 #endif
 
-#if defined(DISABLED)
+#if defined(SYSTEM_LINUX)
     process_ports_linux( scanner );
 #endif 
 }
