@@ -66,6 +66,7 @@
 
 
 int listen_port = DEFAULT_SCAN_AGENT_PORT;
+int quiet_mode  = 0;
 
 /* flag for being daemon, used only for windows. */
 
@@ -105,7 +106,6 @@ char root_cert_file[MAX_PATH_LENGTH]  = PATH_SYSTEM_ROOT_CERT_FILE;
 
 #define ROOT_CERT_PERMISSIONS         0600
 
-
 int nice_level = 0;
 fd_set read_set;
 
@@ -235,8 +235,14 @@ void parse_arguments( int argument_count, char *argument_list[] )
 
     for( count = 1; count < argument_count; count++ )
     {
-       if( ( strcmp( argument_list[count], "-h" ) == 0 ) ||
-           ( strcmp( argument_list[count], "--help" ) == 0 ) )
+       if( ( strcmp( argument_list[count], "-q" ) == 0 ) ||
+           ( strcmp( argument_list[count], "--quiet" ) == 0 ) )
+       {
+            quiet_mode = 1;
+       }
+
+       else if( ( strcmp( argument_list[count], "-h" ) == 0 ) ||
+                ( strcmp( argument_list[count], "--help" ) == 0 ) )
        {
            print_usage();
            halt(0);
@@ -498,7 +504,7 @@ void process()
         check_for_signals();
         wait_for_data();
 
-#ifdef WIN32
+#ifdef HAVE_THREADS
         cleanup_threads();
 #endif
 
@@ -1183,7 +1189,7 @@ void stop_scan()
 
     /* threads should kill their own scan socket and SSL objects. */
 
-#ifndef WIN32
+#ifndef HAVE_THREADS
     osi_close_socket( scan_data_socket );
     osi_ssl_destroy( &scan_data_ssl );
 #endif
@@ -2230,11 +2236,11 @@ void print_usage()
     osi_print_stdout( "Osiris Scan Agent - Version %s\n", OSIRIS_VERSION );
 
 #ifndef WIN32
-    osi_print_stdout( "usage: osirisd [-r <path>] [-n<level>] [-h]\n" );
+    osi_print_stdout( "usage: osirisd [-r <path>] [-p <port>] [-n <level>] [-q] [-h]\n" );
     fprintf( stdout,  "  -n <level>  " );
     osi_print_stdout( "use specified nice level." );
 #else
-    osi_print_stdout( "usage: osirisd [-i|-u] [-h] [-d]\n" );
+    osi_print_stdout( "usage: osirisd [-i|-u] [-p <port>] [-h] [-d] [-q]\n" );
     fprintf( stdout,  "  -i          " );
     osi_print_stdout( "install as a windows service on local machine." );
     fprintf( stdout,  "  -u          " );
@@ -2243,9 +2249,12 @@ void print_usage()
     osi_print_stdout( "run this application as a daemon, not a service." );
 #endif
 
-    fprintf( stdout, "  -p          ");
+    fprintf( stdout, "  -p <port>   ");
     osi_print_stdout( "specify an alternate listen port (default:%d)",
                       DEFAULT_SCAN_AGENT_PORT );
+
+    fprintf( stdout, "  -q          " );
+    osi_print_stdout( "quiet mode, agent produces no log messages." );
     fprintf( stdout, "  -r          " );
     osi_print_stdout( "specify alternate root directory containing root cert.");
     fprintf( stdout, "  -h          " );
