@@ -343,7 +343,7 @@ void process_directory( SCANNER *scanner, const char *directory_path )
             /* into the scanning stream where we can easily  */
             /* quickly, and safely stop threads.             */
 
-#ifdef WIN32
+#ifdef HAVE_THREADS
             if( !WaitForSingleObject( stop_scan_event, 0 ) )
             {
                 osi_scanner_destroy( scanner );
@@ -733,6 +733,7 @@ void populate_scan_record( SCANNER *scanner, SCAN_RECORD *record,
 {
     osi_uint16 type;
     FILE *file_handle = file;
+    int rc;
 
     if( ( scanner == NULL ) || ( record == NULL ) || ( file_stats == NULL ) )
     {
@@ -787,32 +788,39 @@ void populate_scan_record( SCANNER *scanner, SCAN_RECORD *record,
                 {
                     case HASH_MD5:
         
-                        hash_file_md5( scan_record->path, file_handle,
-                                       scan_record->checksum,
-                                       MAX_CHECKSUM_LENGTH );
+                        rc = hash_file_md5( scan_record->path, file_handle,
+                                            scan_record->checksum,
+                                            MAX_CHECKSUM_LENGTH );
                         break;
         
                     case HASH_SHA:
 
-                        hash_file_sha( scan_record->path, file_handle,
-                                       scan_record->checksum,
-                                       MAX_CHECKSUM_LENGTH );
+                        rc = hash_file_sha( scan_record->path, file_handle,
+                                            scan_record->checksum,
+                                            MAX_CHECKSUM_LENGTH );
                         break;
         
                     case HASH_RIPEMD:
         
-                        hash_file_ripemd( scan_record->path, file_handle,
-                                          scan_record->checksum,
-                                          MAX_CHECKSUM_LENGTH );
+                        rc = hash_file_ripemd( scan_record->path, file_handle,
+                                               scan_record->checksum,
+                                               MAX_CHECKSUM_LENGTH );
                         break;
         
                     default:
 
-                        hash_file_md5( scan_record->path, file_handle,
-                                       scan_record->checksum,
-                                       MAX_CHECKSUM_LENGTH );
+                        rc = hash_file_md5( scan_record->path, file_handle,
+                                            scan_record->checksum,
+                                            MAX_CHECKSUM_LENGTH );
                         break;
                 }
+
+                if ( rc != 0 )
+                {
+                    send_scan_error( OSI_ERROR_UNABLE_TO_CSUM_FILE,
+                                "received error (%d) while checksumming (%s)", 
+                                 rc, scan_record->path );
+                }
             }
             
             else
@@ -928,32 +936,39 @@ void populate_scan_record( SCANNER *scanner, SCAN_RECORD *record,
                 {
                     case HASH_MD5:
         
-                        hash_file_md5( scan_record->path, file_handle,
-                                       scan_record->checksum,
-                                       MAX_CHECKSUM_LENGTH );
+                        rc = hash_file_md5( scan_record->path, file_handle,
+                                            scan_record->checksum,
+                                            MAX_CHECKSUM_LENGTH );
                         break;
         
                     case HASH_SHA:
 
-                        hash_file_sha( scan_record->path, file_handle,
-                                       scan_record->checksum,
-                                       MAX_CHECKSUM_LENGTH );
+                        rc = hash_file_sha( scan_record->path, file_handle,
+                                            scan_record->checksum,
+                                            MAX_CHECKSUM_LENGTH );
                         break;
         
                     case HASH_RIPEMD:
         
-                        hash_file_ripemd( scan_record->path, file_handle,
-                                          scan_record->checksum,
-                                          MAX_CHECKSUM_LENGTH );
+                        rc = hash_file_ripemd( scan_record->path, file_handle,
+                                               scan_record->checksum,
+                                               MAX_CHECKSUM_LENGTH );
                         break;
         
                     default:
 
-                        hash_file_md5( scan_record->path, file_handle,
-                                       scan_record->checksum,
-                                       MAX_CHECKSUM_LENGTH );
+                        rc = hash_file_md5( scan_record->path, file_handle,
+                                            scan_record->checksum,
+                                            MAX_CHECKSUM_LENGTH );
                         break;
                 }
+
+                if ( rc != 0 )
+                {
+                    send_scan_error( OSI_ERROR_UNABLE_TO_CSUM_FILE,
+                                "received error (%d) while checksumming (%s)",
+                                 rc, scan_record->path );
+                }
             }
             
             else
@@ -1130,9 +1145,9 @@ int send_scan_data( SCANNER *scanner, SCAN_RECORD *record )
     if( scanner != NULL )
     {
         int record_size;
+        osi_bool is_file = scan_record_is_file_record( record );
 
         initialize_message( &message, MESSAGE_TYPE_SCAN_DATA );
-        type = record->type;
         
         /* we need to wrap the record contents before pushing over */
         /* the network, then we need to pack the structure.        */
@@ -1150,7 +1165,7 @@ int send_scan_data( SCANNER *scanner, SCAN_RECORD *record )
             result = SCANNER_OK;
             scanner->sequence += 1;
 
-            if( scan_record_is_file_record( record ) )
+            if( is_file )
             {
                 scanner->stats.files_scanned++;
             }
