@@ -166,14 +166,11 @@ osi_bool md_compare_record_db( OSI_DB_CTX *context, OSI_DB *db1, OSI_DB *db2 )
     SCAN_RECORD *r1;
     SCAN_RECORD *r2;
 
-    OSI_DB filter_db;
-
     if( ( context == NULL ) || ( db1 == NULL ) || ( db2 == NULL ) )
     {
         return FALSE;
     }
 
-    md_filter_open_database( &filter_db );
     record_size = MAX_SCAN_RECORD_LENGTH;
 
     /* create temporary objects for holding one from each db. */ 
@@ -200,42 +197,19 @@ osi_bool md_compare_record_db( OSI_DB_CTX *context, OSI_DB *db1, OSI_DB *db2 )
 
             if( context->changed_mask )
             {
-                unsigned int unfiltered_mask = 0;
-
-                md_filter_changes( &filter_db, context->host,
-                                   context->changed_mask, name,
-                                   &unfiltered_mask );
-
-                if( unfiltered_mask )
-                {
-                    unsigned int print_mask = ( unfiltered_mask &
-                                                context->changed_mask );
-
-                    record_file_differences( context, r1, r2, print_mask );
-                }
+                record_file_differences( context, r1, r2 );
             }
         }
 
         if ( ( result == OSI_ERROR_DB_ITEM_NOT_FOUND ) &&
              ( context->include_missing ) )
         {
-            unsigned int unfiltered_mask = 0;
+            log_cmp_message( LOG_ID_CMP_FILE_MISSING, context,
+                             "[%s][missing][%s]",
+                             context->host, name );
 
-            /* consult the filter database. */
-
-            md_filter_changes( &filter_db, context->host,
-                               ATTR_MISSING, name,
-                               &unfiltered_mask );
-
-            if( unfiltered_mask )
-            {
-                log_cmp_message( LOG_ID_CMP_FILE_MISSING, context,
-                                 "[%s][missing][%s]",
-                                 context->host, name );
-
-                context->diff_count++;
-                context->missing_count++;
-            }
+            context->diff_count++;
+            context->missing_count++;
         }
 
         result = osi_scan_db_get_next_record( db1, r1, record_size );
@@ -255,22 +229,11 @@ osi_bool md_compare_record_db( OSI_DB_CTX *context, OSI_DB *db1, OSI_DB *db2 )
 
             if( result == OSI_ERROR_DB_ITEM_NOT_FOUND )
             {
-                unsigned int unfiltered_mask = 0;
+                log_cmp_message( LOG_ID_CMP_FILE_NEW, context,
+                                 "[%s][new][%s]", context->host, name );
 
-                /* consult the filter database. */
-
-                md_filter_changes( &filter_db, context->host,
-                                   ATTR_NEW, name,
-                                   &unfiltered_mask );
-
-                if( unfiltered_mask )
-                {
-                    log_cmp_message( LOG_ID_CMP_FILE_NEW, context,
-                                     "[%s][new][%s]", context->host, name );
-
-                    context->diff_count++;
-                    context->new_count++;
-                }
+                context->diff_count++;
+                context->new_count++;
             }
 
             result = osi_scan_db_get_next_record( db2, r2, record_size );
@@ -279,7 +242,6 @@ osi_bool md_compare_record_db( OSI_DB_CTX *context, OSI_DB *db1, OSI_DB *db2 )
 
     osi_free( r1 );
     osi_free( r2 );
-    md_filter_close_database( &filter_db );
 
     return TRUE;
 }
@@ -315,6 +277,8 @@ osi_bool md_compare_system_db( OSI_DB_CTX *context, OSI_DB *db1, OSI_DB *db2 )
                                                        record_size, name );
         if( result == OSI_DB_OK )
         {
+            int rc = 0;
+
             /* compare system data entries. */
 
             char *r1_data = get_scan_record_system_data( r1 );
@@ -326,27 +290,34 @@ osi_bool md_compare_system_db( OSI_DB_CTX *context, OSI_DB *db1, OSI_DB *db2 )
                 {
                     SCAN_RECORD_TEXT_1 *rec = (SCAN_RECORD_TEXT_1 *)r1;
 
-                    log_cmp_message( LOG_ID_CMP_GENERIC_DIFF, context,
+                    rc = log_cmp_message( LOG_ID_CMP_GENERIC_DIFF, context,
                                      "[%s][cmp][%s][%s][%s][%s]",
                                      context->host, rec->module_name,
                                      rec->name, r1_data, r2_data );
 
-                    context->diff_count++;
+                    if ( rc > 0 )
+                    {
+                        context->diff_count++;
+                    }
                 }
             }
         }
 
         else if( result == OSI_ERROR_DB_ITEM_NOT_FOUND )
         {
+            int rc = 0;
             SCAN_RECORD_TEXT_1 *rec = (SCAN_RECORD_TEXT_1 *)r1;
 
-            log_cmp_message( LOG_ID_CMP_GENERIC_MISSING, context,
+            rc = log_cmp_message( LOG_ID_CMP_GENERIC_MISSING, context,
                              "[%s][missing][%s][%s][%s]",
                              context->host, rec->module_name,
                              rec->name, rec->data );
 
-            context->diff_count++;
-            context->missing_count++;
+            if ( rc > 0 )
+            {
+                context->diff_count++;
+                context->missing_count++;
+            }
         }
 
         result = osi_scan_db_get_next_system( db1, r1, record_size );
@@ -365,15 +336,19 @@ osi_bool md_compare_system_db( OSI_DB_CTX *context, OSI_DB *db1, OSI_DB *db2 )
 
         if( result == OSI_ERROR_DB_ITEM_NOT_FOUND )
         {
+            int rc = 0;
             SCAN_RECORD_TEXT_1 *rec = (SCAN_RECORD_TEXT_1 *)r2;
 
-            log_cmp_message( LOG_ID_CMP_GENERIC_NEW, context,
+            rc = log_cmp_message( LOG_ID_CMP_GENERIC_NEW, context,
                              "[%s][new][%s][%s][%s]",
                              context->host, rec->module_name,
                              rec->name, rec->data );
 
-            context->diff_count++;
-            context->new_count++;
+            if ( rc > 0 )
+            {
+                context->diff_count++;
+                context->new_count++;
+            }
         }
 
         result = osi_scan_db_get_next_system( db2, r2, record_size );
@@ -785,28 +760,26 @@ void compare_db_with_default_for_host( OSI_DB *db, OSI_HOST *host )
             if( ( host->notify_flags & OSI_NOTIFY_SCAN_ALWAYS ) ||
                 ( context->diff_count > 0 ) )
             {
-                osi_bool show_url = !( host->db_flags & OSI_DB_AUTOACCEPT );  
+                char *email = config->notify_email;
+                MD_NOTIFY_CTX ctx;
 
                 if( strlen( host->notify_email ) > 0 )
                 {
-                    md_notify( host->notify_email, context, show_url );
+                    email = host->notify_email;
                 }
 
-                else
-                {
-                    md_notify( config->notify_email, context, show_url );
-                }
+                md_notify_init( &ctx, NOTIFY_TYPE_REPORT );            
+                ctx.host = host->name;
+                ctx.email = email;
+                ctx.filename = context->filepath;
+                ctx.diff_count = context->diff_count;
+                ctx.db_name = context->db2_name;
+                ctx.show_url = !( host->db_flags & OSI_DB_AUTOACCEPT );
+
+                md_notify( &ctx );
             }
         }
 
-        /* ALWAYS send notification to admin email. */
-
-        if ( strlen( config->admin_email ) > 0 )
-        {
-            osi_bool show_url = !( host->db_flags & OSI_DB_AUTOACCEPT );
-            md_notify( config->admin_email, context, show_url );
-        }
-
         osi_db_ctx_destroy( context );
     }
 
@@ -845,11 +818,12 @@ void compare_db_with_default_for_host( OSI_DB *db, OSI_HOST *host )
 }
 
 void record_file_differences( OSI_DB_CTX *context, SCAN_RECORD *record1, 
-                              SCAN_RECORD *record2, unsigned int print_mask )
+                              SCAN_RECORD *record2 )
 
 {
     osi_uint16 type;
     unsigned long pre_diff_count;
+    unsigned int print_mask; 
 
     if( record1 == NULL || record2 == NULL || context == NULL )
     {
@@ -858,20 +832,26 @@ void record_file_differences( OSI_DB_CTX *context, SCAN_RECORD *record1,
 
     type = record1->type;
     pre_diff_count = context->diff_count;
+    print_mask     = context->changed_mask;
 
     if( (int)type == SCAN_RECORD_TYPE_UNIX_1 )
     {
+        int rc = 0;
+
         SCAN_RECORD_UNIX_1 *r1 = (SCAN_RECORD_UNIX_1 *)record1;
         SCAN_RECORD_UNIX_1 *r2 = (SCAN_RECORD_UNIX_1 *)record2;
 
         if( print_mask & ATTR_CHECKSUM )
         {
-            log_cmp_message( LOG_ID_CMP_CHECKSUM, context,
+            rc = log_cmp_message( LOG_ID_CMP_CHECKSUM, context,
                            "[%s][cmp][%s][checksum][%s][%s]",
                            context->host, r1->path, r1->checksum,r2->checksum );
 
-            context->diff_count++;
-            context->checksum_diff_count++;
+            if ( rc > 0 )
+            {
+                context->diff_count++;
+                context->checksum_diff_count++;
+            }
         }
 
         if( print_mask & ATTR_DEVICE )
@@ -884,17 +864,20 @@ void record_file_differences( OSI_DB_CTX *context, SCAN_RECORD *record1,
             osi_snprintf( left, sizeof(left), "%llu", r1->device );
             osi_snprintf( right, sizeof(right), "%llu", r2->device );
 
-            log_cmp_message( LOG_ID_CMP_DEVICE, context,
+            rc = log_cmp_message( LOG_ID_CMP_DEVICE, context,
                              "[%s][cmp][%s][device][%s][%s]",
                              context->host, r1->path, left, right );
             #else
 
-            log_cmp_message( LOG_ID_CMP_DEVICE, context,
+            rc = log_cmp_message( LOG_ID_CMP_DEVICE, context,
                              "[%s][cmp][%s][device][%llu][%llu]",
                              context->host, r1->path, r1->device, r2->device );
             #endif
 
-            context->diff_count++;
+            if ( rc > 0 )
+            {
+                context->diff_count++;
+            }
         }
 
         if( print_mask & ATTR_INODE )
@@ -907,30 +890,36 @@ void record_file_differences( OSI_DB_CTX *context, SCAN_RECORD *record1,
             osi_snprintf( left, sizeof(left), "%llu", r1->inode );
             osi_snprintf( right, sizeof(right), "%llu", r2->inode );
 
-            log_cmp_message( LOG_ID_CMP_INODE, context,
+            rc = log_cmp_message( LOG_ID_CMP_INODE, context,
                              "[%s][cmp][%s][inode][%s][%s]",
                              context->host, r1->path, left, right );
 
             #else
 
             
-            log_cmp_message( LOG_ID_CMP_INODE, context,
+            rc = log_cmp_message( LOG_ID_CMP_INODE, context,
                              "[%s][cmp][%s][inode][%llu][%llu]",
                               context->host,r1->path, r1->inode, r2->inode );
             #endif
 
-            context->diff_count++;
+            if ( rc > 0 )
+            {
+                context->diff_count++;
+            }
         }
 
         if( print_mask & ATTR_PERMISSIONS )
         {
-            log_cmp_message( LOG_ID_CMP_PERM, context,
+            rc = log_cmp_message( LOG_ID_CMP_PERM, context,
                              "[%s][cmp][%s][perm][%s][%s]", context->host,
                              r1->path, r1->permissions_string, 
                              r2->permissions_string );
 
-            context->diff_count++;
-            context->perm_diff_count++;
+            if ( rc > 0 )
+            {
+                context->diff_count++;
+                context->perm_diff_count++;
+            }
         }
 
         if( print_mask & ATTR_LINKS )
@@ -943,18 +932,21 @@ void record_file_differences( OSI_DB_CTX *context, SCAN_RECORD *record1,
             osi_snprintf( left, sizeof(left), "%llu", r1->links );
             osi_snprintf( right, sizeof(right), "%llu", r2->links );
 
-            log_cmp_message( LOG_ID_CMP_SYMLINKS, context,
+            rc = log_cmp_message( LOG_ID_CMP_SYMLINKS, context,
                              "[%s][cmp][%s][links][%s][%s]",
                              context->host, r1->path, left, right );
             #else
 
-            log_cmp_message( LOG_ID_CMP_SYMLINKS, context,
+            rc = log_cmp_message( LOG_ID_CMP_SYMLINKS, context,
                              "[%s][cmp][%s][links][%llu][%llu]",
                              context->host,
                              r1->path, r1->links, r2->links );
             #endif
 
-            context->diff_count++;
+            if ( rc > 0 )
+            {
+                context->diff_count++;
+            } 
         }
 
         if( print_mask & ATTR_UID )
@@ -967,17 +959,20 @@ void record_file_differences( OSI_DB_CTX *context, SCAN_RECORD *record1,
             osi_snprintf( left, sizeof(left), "%llu", r1->uid );
             osi_snprintf( right, sizeof(right), "%llu", r2->uid );
 
-            log_cmp_message( LOG_ID_CMP_UID, context,
+            rc = log_cmp_message( LOG_ID_CMP_UID, context,
                              "[%s][cmp][%s][uid][%s][%s]",
                              context->host, r1->path, left, right );
             #else
 
-            log_cmp_message( LOG_ID_CMP_UID, context,
+            rc = log_cmp_message( LOG_ID_CMP_UID, context,
                              "[%s][cmp][%s][uid][%llu][%llu]",
                              context->host, r1->path, r1->uid, r2->uid );
             #endif
 
-            context->diff_count++;
+            if ( rc > 0 )
+            {
+                context->diff_count++;
+            }
         }
 
         if( print_mask & ATTR_GID )
@@ -990,17 +985,20 @@ void record_file_differences( OSI_DB_CTX *context, SCAN_RECORD *record1,
             osi_snprintf( left, sizeof(left), "%llu", r1->gid );
             osi_snprintf( right, sizeof(right), "%llu", r2->gid );
 
-            log_cmp_message( LOG_ID_CMP_GID, context,
+            rc = log_cmp_message( LOG_ID_CMP_GID, context,
                              "[%s][cmp][%s][gid][%s][%s]",
                              context->host, r1->path, left, right );
             #else
 
-            log_cmp_message( LOG_ID_CMP_GID, context,
+            rc = log_cmp_message( LOG_ID_CMP_GID, context,
                              "[%s][cmp][%s][gid][%llu][%llu]",
                              context->host, r1->path, r1->gid, r2->gid );
             #endif
 
-            context->diff_count++;
+            if ( rc > 0 )
+            {
+                context->diff_count++;
+            }
         }
 
         if( print_mask & ATTR_MTIME )
@@ -1014,11 +1012,14 @@ void record_file_differences( OSI_DB_CTX *context, SCAN_RECORD *record1,
             osi_strlcpy( right_mtime, osi_time_to_string( (long)r2->mtime ),
                          sizeof( right_mtime ) );
 
-            log_cmp_message( LOG_ID_CMP_MTIME, context,
+            rc = log_cmp_message( LOG_ID_CMP_MTIME, context,
                              "[%s][cmp][%s][mtime][%s][%s]",
                              context->host, r1->path, left_mtime, right_mtime );
 
-            context->diff_count++;
+            if ( rc > 0 )
+            {
+                context->diff_count++;
+            }
         }
 
         if( print_mask & ATTR_ATIME )
@@ -1032,11 +1033,14 @@ void record_file_differences( OSI_DB_CTX *context, SCAN_RECORD *record1,
             osi_strlcpy( right_atime, osi_time_to_string( (long)r2->atime ),
                          sizeof( right_atime ) );
 
-            log_cmp_message( LOG_ID_CMP_ATIME, context,
+            rc = log_cmp_message( LOG_ID_CMP_ATIME, context,
                              "[%s][cmp][%s][atime][%s][%s]",
                              context->host, r1->path, left_atime, right_atime );
 
-            context->diff_count++;
+            if ( rc > 0 )
+            {
+                context->diff_count++;
+            }
         }
 
         if( print_mask & ATTR_CTIME )
@@ -1050,11 +1054,14 @@ void record_file_differences( OSI_DB_CTX *context, SCAN_RECORD *record1,
             osi_strlcpy( right_ctime, osi_time_to_string( (long)r2->ctime ),
                          sizeof( right_ctime ) );
 
-            log_cmp_message( LOG_ID_CMP_CTIME, context,
+            rc = log_cmp_message( LOG_ID_CMP_CTIME, context,
                              "[%s][cmp][%s][ctime][%s][%s]",
                              context->host, r1->path, left_ctime, right_ctime );
 
-            context->diff_count++;
+            if ( rc > 0 )
+            {
+                context->diff_count++;
+            }
         }
 
         if( print_mask & ATTR_DEVICE_TYPE ) 
@@ -1067,18 +1074,21 @@ void record_file_differences( OSI_DB_CTX *context, SCAN_RECORD *record1,
             osi_snprintf( left, sizeof(left), "%llu", r1->device_type );
             osi_snprintf( right, sizeof(right), "%llu", r2->device_type );
 
-            log_cmp_message( LOG_ID_CMP_DEVICETYPE, context,
+            rc = log_cmp_message( LOG_ID_CMP_DEVICETYPE, context,
                              "[%s][cmp][%s][devicetype][%s][%s]",
                              context->host, r1->path, left, right );
             #else
 
-           log_cmp_message( LOG_ID_CMP_DEVICETYPE, context, 
+           rc = log_cmp_message( LOG_ID_CMP_DEVICETYPE, context, 
                            "[%s][cmp][%s][devicetype][%llu][%llu]",
                             context->host, r1->path,
                             r1->device_type, r2->device_type );
             #endif
-
-            context->diff_count++;
+            
+            if ( rc > 0 )
+            {
+                context->diff_count++;
+            }
         }
 
         if( print_mask & ATTR_BYTES )
@@ -1091,17 +1101,20 @@ void record_file_differences( OSI_DB_CTX *context, SCAN_RECORD *record1,
             osi_snprintf( left, sizeof(left), "%llu", r1->bytes );
             osi_snprintf( right, sizeof(right), "%llu", r2->bytes );
 
-            log_cmp_message( LOG_ID_CMP_BYTES, context,
+            rc = log_cmp_message( LOG_ID_CMP_BYTES, context,
                              "[%s][cmp][%s][bytes][%s][%s]",
                              context->host, r1->path, left, right );
             #else
 
-            log_cmp_message( LOG_ID_CMP_BYTES, context,
+            rc = log_cmp_message( LOG_ID_CMP_BYTES, context,
                              "[%s][cmp][%s][bytes][%llu][%llu]",
                              context->host, r1->path, r1->bytes, r2->bytes );
             #endif
-
-            context->diff_count++;
+    
+            if ( rc > 0 )
+            {
+                context->diff_count++;
+            }
         }
 
         if( print_mask & ATTR_BLOCKS )
@@ -1114,17 +1127,20 @@ void record_file_differences( OSI_DB_CTX *context, SCAN_RECORD *record1,
             osi_snprintf( left, sizeof(left), "%llu", r1->blocks );
             osi_snprintf( right, sizeof(right), "%llu", r2->blocks );
 
-            log_cmp_message( LOG_ID_CMP_BLOCKS, context,
+            rc = log_cmp_message( LOG_ID_CMP_BLOCKS, context,
                              "[%s][cmp][%s][blocks][%s][%s]",
                              context->host, r1->path, left, right );
             #else
 
-            log_cmp_message( LOG_ID_CMP_BLOCKS, context,
+            rc = log_cmp_message( LOG_ID_CMP_BLOCKS, context,
                              "[%s][cmp][%s][blocks][%llu][%llu]",
                              context->host, r1->path, r1->blocks, r2->blocks );
             #endif
 
-            context->diff_count++;
+            if ( rc > 0 )
+            {
+                context->diff_count++;
+            }
         }
 
         if( print_mask & ATTR_BLOCK_SIZE ) 
@@ -1137,18 +1153,21 @@ void record_file_differences( OSI_DB_CTX *context, SCAN_RECORD *record1,
             osi_snprintf( left, sizeof(left), "%llu", r1->block_size );
             osi_snprintf( right, sizeof(right), "%llu", r2->block_size );
 
-            log_cmp_message( LOG_ID_CMP_BLOCKSIZE, context,
+            rc = log_cmp_message( LOG_ID_CMP_BLOCKSIZE, context,
                              "[%s][cmp][%s][blocksize][%s][%s]",
                              context->host, r1->path, left, right );
             #else
 
-            log_cmp_message( LOG_ID_CMP_BLOCKSIZE, context,
+            rc = log_cmp_message( LOG_ID_CMP_BLOCKSIZE, context,
                              "[%s][cmp][%s][blocksize][%llu][%llu]",
                              context->host, r1->path,
                              r1->block_size, r2->block_size );
             #endif
 
-            context->diff_count++;
+            if ( rc > 0 )
+            {
+                context->diff_count++;
+            }
         }
 
         /* if we had a change, look to update some of our stats. */
@@ -1187,18 +1206,23 @@ void record_file_differences( OSI_DB_CTX *context, SCAN_RECORD *record1,
 
     else if( (int)type == SCAN_RECORD_TYPE_WINNT_1 )
     {
+        int rc = 0;
+
         SCAN_RECORD_WINNT_1 *r1 = (SCAN_RECORD_WINNT_1 *)record1;
         SCAN_RECORD_WINNT_1 *r2 = (SCAN_RECORD_WINNT_1 *)record2;
 
         if( print_mask & ATTR_CHECKSUM ) 
         {
-            log_cmp_message( LOG_ID_CMP_CHECKSUM, context,
+            rc = log_cmp_message( LOG_ID_CMP_CHECKSUM, context,
                              "[%s][cmp][%s][checksum][%s][%s]",
                              context->host, r1->path,
                              r1->checksum, r2->checksum );
-
-            context->diff_count++;
-            context->checksum_diff_count++;
+            
+            if ( rc > 0 )
+            {
+                context->diff_count++;
+                context->checksum_diff_count++;
+            }
         }
 
         if( print_mask & ATTR_DEVICE ) 
@@ -1211,18 +1235,21 @@ void record_file_differences( OSI_DB_CTX *context, SCAN_RECORD *record1,
             osi_snprintf( left, sizeof(left), "%llu", r1->device );
             osi_snprintf( right, sizeof(right), "%llu", r2->device );
 
-            log_cmp_message( LOG_ID_CMP_DEVICE, context,
+            rc = log_cmp_message( LOG_ID_CMP_DEVICE, context,
                              "[%s][cmp][%s][device][%s][%s]",
                              context->host, r1->path, left, right );
             #else
 
-            log_cmp_message( LOG_ID_CMP_DEVICE, context,
+            rc = log_cmp_message( LOG_ID_CMP_DEVICE, context,
                              "[%s][cmp][%s][device][%llu][%llu]",
                              context->host, r1->path, 
                              r1->device, r2->device );
             #endif
 
-            context->diff_count++;
+            if ( rc > 0 )
+            {
+                context->diff_count++;
+            }
         }
 
         if( print_mask & ATTR_BYTES )
@@ -1235,18 +1262,21 @@ void record_file_differences( OSI_DB_CTX *context, SCAN_RECORD *record1,
             osi_snprintf( left, sizeof(left), "%llu", r1->bytes );
             osi_snprintf( right, sizeof(right), "%llu", r2->bytes );
 
-            log_cmp_message( LOG_ID_CMP_BYTES, context,
+            rc = log_cmp_message( LOG_ID_CMP_BYTES, context,
                              "[%s][cmp][%s][bytes][%s][%s]",
                              context->host, r1->path, left, right );
             #else
 
-            log_cmp_message( LOG_ID_CMP_BYTES, context,
+            rc = log_cmp_message( LOG_ID_CMP_BYTES, context,
                              "[%s][cmp][%s][bytes][%llu][%llu]",
                              context->host, r1->path,
                              r1->bytes, r2->bytes );
             #endif
 
-            context->diff_count++;
+            if ( rc > 0 )
+            {
+                context->diff_count++;
+            }
         }
 
         if( print_mask & ATTR_MTIME )
@@ -1261,11 +1291,14 @@ void record_file_differences( OSI_DB_CTX *context, SCAN_RECORD *record1,
                          sizeof( right_time ) );
 
 
-            log_cmp_message( LOG_ID_CMP_MTIME, context,
+            rc = log_cmp_message( LOG_ID_CMP_MTIME, context,
                              "[%s][cmp][%s][mtime][%s][%s]",
                              context->host, r1->path, left_time, right_time );
 
-            context->diff_count++;
+            if ( rc > 0 )
+            {
+                context->diff_count++;
+            }
         }
 
         if( print_mask & ATTR_ATIME )
@@ -1279,11 +1312,14 @@ void record_file_differences( OSI_DB_CTX *context, SCAN_RECORD *record1,
             osi_strlcpy( right_time, osi_time_to_string( (long)r2->atime ),
                          sizeof( right_time ) );
 
-            log_cmp_message( LOG_ID_CMP_ATIME, context,
+            rc = log_cmp_message( LOG_ID_CMP_ATIME, context,
                              "[%s][cmp][%s][atime][%s][%s]",
                              context->host, r1->path, left_time, right_time );
 
-            context->diff_count++;
+            if ( rc > 0 )
+            {
+                context->diff_count++;
+            }
         }
 
         if( print_mask & ATTR_CTIME )
@@ -1297,33 +1333,42 @@ void record_file_differences( OSI_DB_CTX *context, SCAN_RECORD *record1,
             osi_strlcpy( right_time, osi_time_to_string( (long)r2->ctime ),
                          sizeof( right_time ) );
 
-            log_cmp_message( LOG_ID_CMP_CTIME, context,
+            rc = log_cmp_message( LOG_ID_CMP_CTIME, context,
                              "[%s][cmp][%s][ctime][%s][%s]",
                              context->host, r1->path, left_time, right_time );
 
-            context->diff_count++;
+            if ( rc > 0 )
+            {
+                context->diff_count++;
+            }
         }
 
         if( print_mask & ATTR_OWNER_SID )
         {
-            log_cmp_message( LOG_ID_CMP_OWNER_SID, context,
+            rc = log_cmp_message( LOG_ID_CMP_OWNER_SID, context,
                       "[%s][cmp][%s][owner_sid][%s:%s][%s:%s]",
                       context->host, r1->path,
                       r1->owner, r1->owner_sid,
                       r2->owner, r2->owner_sid );
 
-            context->diff_count++;
+            if ( rc > 0 )
+            {
+                context->diff_count++;
+            }
         }
 
         if( print_mask & ATTR_GROUP_SID )
         {
-            log_cmp_message( LOG_ID_CMP_GROUP_SID, context,
+            rc = log_cmp_message( LOG_ID_CMP_GROUP_SID, context,
                       "[%s][cmp][%s][group_sid][%s:%s][%s:%s]",
                       context->host, r1->path,
                       r1->group, r1->group_sid,
                       r2->group, r2->group_sid );
 
-            context->diff_count++;
+            if ( rc > 0 )
+            {
+                context->diff_count++;
+            }
         }
 
         if( print_mask & ATTR_WIN32_FILE )
@@ -1333,11 +1378,14 @@ void record_file_differences( OSI_DB_CTX *context, SCAN_RECORD *record1,
             get_win32_file_attr_delta_string( r1->attributes, r2->attributes,
                                               buffer, sizeof( buffer ) );
 
-            log_cmp_message( LOG_ID_CMP_WIN_FILE_ATTR, context,
+            rc = log_cmp_message( LOG_ID_CMP_WIN_FILE_ATTR, context,
                              "[%s][cmp][%s][file_attributes][%s]",
                              context->host, r1->path, buffer ); 
 
-            context->diff_count++;
+            if ( rc > 0 )
+            {
+                context->diff_count++;
+            }
         } 
 
         /* END WIN32 compare. */
