@@ -350,14 +350,6 @@ void process_request( SSL *ssl, CONTROL_REQUEST *request )
             process_remove_db( ssl, request );
             break;
 
-        case CONTROL_COMMAND_IMPORT_DEFAULT_CONFIG:
-
-            log_info( LOG_ID_PEER_MSG, request->host,
-                      "received push-default-config request." );
-
-            process_import_default_config( ssl, request );
-            break;
-
         case CONTROL_COMMAND_SEND_NOTIFY_TEST:
 
             log_info( LOG_ID_PEER_MSG, NULL,
@@ -1923,37 +1915,6 @@ void process_push_config( SSL *ssl, CONTROL_REQUEST *request )
     }
 }
 
-void process_import_default_config( SSL *ssl, CONTROL_REQUEST *request )
-{
-    int result;
-    OSI_SCAN_CONFIG *cfg;
-
-    cfg = osi_host_read_default_config( request->buffer );
-
-    if( ( cfg == NULL ) || ( cfg->data == NULL ) )
-    {
-        osi_ssl_write_error_message( OSI_ERROR_CONFIG_DOES_NOT_EXIST,
-                                     "specified config does not exist", ssl );
-        return;
-    }
-
-    result = osi_config_write_with_name( cfg, request->host,
-                                         DEFAULT_CONFIG_NAME );
-
-    if( result == OSI_OK )
-    {
-        osi_ssl_write_success_message( ssl );
-    }
-
-    else
-    {
-        osi_ssl_write_error_message( result, "error storing config file.",
-                                     ssl );
-    }
-
-    osi_config_destroy( cfg );
-}
-
 void process_set_base_db( SSL *ssl, CONTROL_REQUEST *request )
 {
     OSI_HOST_BRIEF *host_brief;
