@@ -32,8 +32,6 @@ osi_bool md_filter_create_database( const char *filter_db_path );
 osi_bool md_filter_open_database( OSI_DB *filter_db );
 osi_bool md_filter_close_database( OSI_DB *filter_db );
 
-void md_filter_changes( OSI_DB *filter_db, char *host,
-                        unsigned int file_attr, char *path,
-                        unsigned int *unfiltered_mask );
+osi_bool md_filter_pattern( OSI_DB *filter_db, const char *pattern );
 
 #endif
